Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/symphra_modules/__init__.py | (no class) | 6 | 0 | 47 | 0 | 0 | 100.00%
src/symphra_modules/abc.py | ModuleInterface | 0 | 0 | 20 | 0 | 0 | 100.00%
src/symphra_modules/abc.py | BaseModule | 16 | 0 | 1 | 6 | 1 | 95.45%
src/symphra_modules/abc.py | (no class) | 32 | 0 | 28 | 8 | 1 | 97.50%
src/symphra_modules/config.py | ModuleState | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/config.py | ModuleMetadata | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/config.py | ModuleInfo | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/config.py | (no class) | 31 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/__init__.py | (no class) | 3 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/bus.py | EventBus | 30 | 2 | 0 | 18 | 2 | 87.50%
src/symphra_modules/events/bus.py | (no class) | 15 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | Event | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | ModuleLoadedEvent | 1 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | ModuleInstalledEvent | 1 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | ModuleStartedEvent | 1 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | ModuleStoppedEvent | 1 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | ModuleUninstalledEvent | 1 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | ModuleUnregisteredEvent | 1 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | ModuleErrorEvent | 4 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/events/types.py | (no class) | 31 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | ModuleError | 2 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | ModuleNotFoundException | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | ModuleLoadError | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | ModuleConfigError | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | ConfigValidationError | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | ModuleStateError | 3 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | ModuleDependencyError | 3 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | EventError | 0 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/exceptions.py | (no class) | 11 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/loader/__init__.py | (no class) | 4 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/loader/base.py | ModuleLoader | 22 | 5 | 16 | 12 | 4 | 67.65%
src/symphra_modules/loader/base.py | (no class) | 10 | 0 | 4 | 0 | 0 | 100.00%
src/symphra_modules/loader/directory.py | DirectoryLoader | 81 | 51 | 0 | 38 | 2 | 42.02%
src/symphra_modules/loader/directory.py | (no class) | 17 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/loader/package.py | PackageLoader | 17 | 1 | 0 | 6 | 1 | 91.30%
src/symphra_modules/loader/package.py | (no class) | 8 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/manager.py | ModuleManager | 129 | 43 | 0 | 52 | 8 | 65.19%
src/symphra_modules/manager.py | (no class) | 31 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/registry.py | ModuleRegistry | 93 | 20 | 0 | 16 | 3 | 78.90%
src/symphra_modules/registry.py | (no class) | 26 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/resolver/__init__.py | (no class) | 2 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/resolver/dependency.py | DependencyGraph | 14 | 0 | 0 | 4 | 1 | 94.44%
src/symphra_modules/resolver/dependency.py | DependencyResolver | 63 | 0 | 0 | 44 | 1 | 99.07%
src/symphra_modules/resolver/dependency.py | (no class) | 17 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/utils/__init__.py | (no class) | 5 | 0 | 0 | 0 | 0 | 100.00%
src/symphra_modules/utils/logger.py | Logger | 0 | 0 | 10 | 0 | 0 | 100.00%
src/symphra_modules/utils/logger.py | StandardLogger | 18 | 5 | 0 | 4 | 2 | 68.18%
src/symphra_modules/utils/logger.py | (no class) | 15 | 1 | 15 | 0 | 0 | 93.33%
Total |  | 765 | 128 | 141 | 208 | 26 | 80.88%

No items found using the specified filter.